==> smartgwtee-eval-5.0p.zip: com/smartgwt/client/docs/AutoTest.java <==

package com.smartgwt.client.docs;

/**
 * The following APIs are all related to AutoTest.
 * @see com.smartgwt.client.util.AutoTest
 * @see com.smartgwt.client.util.AutoTest#implicitNetworkWait
 * @see com.smartgwt.client.util.AutoTest#testRoot
 * @see com.smartgwt.client.util.AutoTest#getLocator
 * @see com.smartgwt.client.util.AutoTest#locateCanvasFromDOMElement
 * @see com.smartgwt.client.util.AutoTest#getElement
 * @see com.smartgwt.client.util.AutoTest#getObject
 * @see com.smartgwt.client.util.AutoTest#getValue
 * @see com.smartgwt.client.util.AutoTest#getPageCoords
 * @see com.smartgwt.client.util.AutoTest#setTestRoot
 * @see com.smartgwt.client.util.AutoTest#isElementClickable
 * @see com.smartgwt.client.util.AutoTest#isCanvasDone
 * @see com.smartgwt.client.util.AutoTest#isTileLayoutDone
 * @see com.smartgwt.client.util.AutoTest#isTileGridDone
 * @see com.smartgwt.client.util.AutoTest#isGridDone
 * @see com.smartgwt.client.util.AutoTest#isSystemDone
 * @see com.smartgwt.client.widgets.Canvas#getLocateChildrenBy
 * @see com.smartgwt.client.widgets.Canvas#getLocateChildrenType
 * @see com.smartgwt.client.widgets.Canvas#getLocatePeersBy
 * @see com.smartgwt.client.widgets.Canvas#getLocatePeersType
 * @see com.smartgwt.client.widgets.layout.Layout#getLocateMembersBy
 * @see com.smartgwt.client.widgets.layout.Layout#getLocateMembersType
 * @see com.smartgwt.client.widgets.layout.SectionStack#getLocateSectionsBy
 * @see com.smartgwt.client.widgets.layout.SectionStack#getLocateSectionsType
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getLocateItemBy
 * @see com.smartgwt.client.widgets.tab.TabSet#getLocateTabsBy
 * @see com.smartgwt.client.widgets.grid.ListGrid#getLocateRowsBy
 * @see com.smartgwt.client.widgets.grid.ListGrid#getLocateColumnsBy
 * @see com.smartgwt.client.types.AutoTestLocator
 * @see com.smartgwt.client.types.LocatorStrategy
 * @see com.smartgwt.client.types.LocatorTypeStrategy
 */
public interface AutoTest {
}

==> smartgwtee-eval-12.1p.zip: com/smartgwt/client/docs/AutoTest.java <==

package com.smartgwt.client.docs;

/**
 * The following APIs are all related to AutoTest.
 * @see com.smartgwt.client.docs.AutoTestLocator
 * @see com.smartgwt.client.types.LocatorStrategy
 * @see com.smartgwt.client.types.LocatorTypeStrategy
 * @see com.smartgwt.client.util.AutoTest#getLocator
 * @see com.smartgwt.client.util.AutoTest#getLocatorWithIndicators
 * @see com.smartgwt.client.util.AutoTest#locateCanvasFromDOMElement
 * @see com.smartgwt.client.util.AutoTest#getElement
 * @see com.smartgwt.client.util.AutoTest#getObject
 * @see com.smartgwt.client.util.AutoTest#getValue
 * @see com.smartgwt.client.util.AutoTest#getPageCoords
 * @see com.smartgwt.client.util.AutoTest#setTestRoot
 * @see com.smartgwt.client.util.AutoTest#isCanvasDone
 * @see com.smartgwt.client.util.AutoTest#isTileLayoutDone
 * @see com.smartgwt.client.util.AutoTest#isTileGridDone
 * @see com.smartgwt.client.util.AutoTest#isFormDone
 * @see com.smartgwt.client.util.AutoTest#isItemDone
 * @see com.smartgwt.client.util.AutoTest#isGridDone
 * @see com.smartgwt.client.util.AutoTest#isElementClickable
 * @see com.smartgwt.client.util.AutoTest#isElementReadyForKeyPresses
 * @see com.smartgwt.client.util.AutoTest#isSystemDone
 * @see com.smartgwt.client.util.AutoTest
 * @see com.smartgwt.client.util.QualityIndicatedLocator
 * @see com.smartgwt.client.util.AutoTest#implicitNetworkWait
 * @see com.smartgwt.client.util.AutoTest#testRoot
 * @see com.smartgwt.client.widgets.Canvas#getLocatorName
 * @see com.smartgwt.client.widgets.Canvas#getLocateChildrenBy
 * @see com.smartgwt.client.widgets.Canvas#getLocateChildrenType
 * @see com.smartgwt.client.widgets.Canvas#getLocatePeersBy
 * @see com.smartgwt.client.widgets.Canvas#getLocatePeersType
 * @see com.smartgwt.client.widgets.layout.Layout#getLocateMembersBy
 * @see com.smartgwt.client.widgets.layout.Layout#getLocateMembersType
 * @see com.smartgwt.client.widgets.layout.SectionStack#getLocateSectionsBy
 * @see com.smartgwt.client.widgets.layout.SectionStack#getLocateSectionsType
 * @see com.smartgwt.client.widgets.form.fields.FormItem#getLocateItemBy
 * @see com.smartgwt.client.widgets.tab.TabSet#getLocateTabsBy
 * @see com.smartgwt.client.widgets.grid.ListGrid#getLocateRowsBy
 * @see com.smartgwt.client.widgets.grid.ListGrid#getLocateColumnsBy
 */
public interface AutoTest {
}
